Documentation
¶
Index ¶
- func WrapDebug(name string, fn cron.FuncJob) cron.FuncJob
- type Accounter
- type CronLogger
- type Logger
- type MTLAPGauge
- type MTLAPGaugeParams
- type Metricer
- type Metrics
- type MockAccounter
- type MockAccounter_Accounts_Call
- func (_c *MockAccounter_Accounts_Call) Return(accounts horizon.AccountsPage, err error) *MockAccounter_Accounts_Call
- func (_c *MockAccounter_Accounts_Call) Run(run func(request horizonclient.AccountsRequest)) *MockAccounter_Accounts_Call
- func (_c *MockAccounter_Accounts_Call) RunAndReturn(run func(horizonclient.AccountsRequest) (horizon.AccountsPage, error)) *MockAccounter_Accounts_Call
- type MockAccounter_Expecter
- type MockAccounter_NextAccountsPage_Call
- func (_c *MockAccounter_NextAccountsPage_Call) Return(accounts horizon.AccountsPage, err error) *MockAccounter_NextAccountsPage_Call
- func (_c *MockAccounter_NextAccountsPage_Call) Run(run func(page horizon.AccountsPage)) *MockAccounter_NextAccountsPage_Call
- func (_c *MockAccounter_NextAccountsPage_Call) RunAndReturn(run func(horizon.AccountsPage) (horizon.AccountsPage, error)) *MockAccounter_NextAccountsPage_Call
- type MockLogger
- type MockLogger_Debug_Call
- type MockLogger_Error_Call
- type MockLogger_Expecter
- type MockLogger_Info_Call
- type MockMetricer
- type MockMetricer_Expecter
- type MockMetricer_MTLAPGaugeInc_Call
- func (_c *MockMetricer_MTLAPGaugeInc_Call) Return() *MockMetricer_MTLAPGaugeInc_Call
- func (_c *MockMetricer_MTLAPGaugeInc_Call) Run(run func(p MTLAPGaugeParams)) *MockMetricer_MTLAPGaugeInc_Call
- func (_c *MockMetricer_MTLAPGaugeInc_Call) RunAndReturn(run func(MTLAPGaugeParams)) *MockMetricer_MTLAPGaugeInc_Call
- type MockMetricer_MTLAPGaugeReset_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Accounter ¶
type Accounter interface {
Accounts(request horizonclient.AccountsRequest) (accounts horizon.AccountsPage, err error)
NextAccountsPage(page horizon.AccountsPage) (accounts horizon.AccountsPage, err error)
}
type CronLogger ¶
type CronLogger struct {
// contains filtered or unexported fields
}
func NewCronLogger ¶
func NewCronLogger(l *slog.Logger) *CronLogger
func (*CronLogger) Error ¶
func (c *CronLogger) Error(err error, msg string, keysAndValues ...interface{})
func (*CronLogger) Info ¶
func (c *CronLogger) Info(msg string, keysAndValues ...interface{})
type MTLAPGauge ¶
type MTLAPGauge struct {
// contains filtered or unexported fields
}
func NewMTLAPGauge ¶
func NewMTLAPGauge(l Logger, cl Accounter, m Metricer) *MTLAPGauge
func (*MTLAPGauge) Update ¶
func (g *MTLAPGauge) Update()
type MTLAPGaugeParams ¶
type Metricer ¶
type Metricer interface {
MTLAPGaugeReset()
MTLAPGaugeInc(p MTLAPGaugeParams)
}
type Metrics ¶
type Metrics struct {
// contains filtered or unexported fields
}
func NewMetrics ¶
func (*Metrics) MTLAPGaugeInc ¶
func (m *Metrics) MTLAPGaugeInc(p MTLAPGaugeParams)
func (*Metrics) MTLAPGaugeReset ¶
func (m *Metrics) MTLAPGaugeReset()
type MockAccounter ¶
MockAccounter is an autogenerated mock type for the Accounter type
func NewMockAccounter ¶
func NewMockAccounter(t interface {
mock.TestingT
Cleanup(func())
}) *MockAccounter
NewMockAccounter creates a new instance of MockAccounter. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockAccounter) Accounts ¶
func (_m *MockAccounter) Accounts(request horizonclient.AccountsRequest) (horizon.AccountsPage, error)
Accounts provides a mock function with given fields: request
func (*MockAccounter) EXPECT ¶
func (_m *MockAccounter) EXPECT() *MockAccounter_Expecter
func (*MockAccounter) NextAccountsPage ¶
func (_m *MockAccounter) NextAccountsPage(page horizon.AccountsPage) (horizon.AccountsPage, error)
NextAccountsPage provides a mock function with given fields: page
type MockAccounter_Accounts_Call ¶
MockAccounter_Accounts_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Accounts'
func (*MockAccounter_Accounts_Call) Return ¶
func (_c *MockAccounter_Accounts_Call) Return(accounts horizon.AccountsPage, err error) *MockAccounter_Accounts_Call
func (*MockAccounter_Accounts_Call) Run ¶
func (_c *MockAccounter_Accounts_Call) Run(run func(request horizonclient.AccountsRequest)) *MockAccounter_Accounts_Call
func (*MockAccounter_Accounts_Call) RunAndReturn ¶
func (_c *MockAccounter_Accounts_Call) RunAndReturn(run func(horizonclient.AccountsRequest) (horizon.AccountsPage, error)) *MockAccounter_Accounts_Call
type MockAccounter_Expecter ¶
type MockAccounter_Expecter struct {
// contains filtered or unexported fields
}
func (*MockAccounter_Expecter) Accounts ¶
func (_e *MockAccounter_Expecter) Accounts(request interface{}) *MockAccounter_Accounts_Call
Accounts is a helper method to define mock.On call
- request horizonclient.AccountsRequest
func (*MockAccounter_Expecter) NextAccountsPage ¶
func (_e *MockAccounter_Expecter) NextAccountsPage(page interface{}) *MockAccounter_NextAccountsPage_Call
NextAccountsPage is a helper method to define mock.On call
- page horizon.AccountsPage
type MockAccounter_NextAccountsPage_Call ¶
MockAccounter_NextAccountsPage_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'NextAccountsPage'
func (*MockAccounter_NextAccountsPage_Call) Return ¶
func (_c *MockAccounter_NextAccountsPage_Call) Return(accounts horizon.AccountsPage, err error) *MockAccounter_NextAccountsPage_Call
func (*MockAccounter_NextAccountsPage_Call) Run ¶
func (_c *MockAccounter_NextAccountsPage_Call) Run(run func(page horizon.AccountsPage)) *MockAccounter_NextAccountsPage_Call
func (*MockAccounter_NextAccountsPage_Call) RunAndReturn ¶
func (_c *MockAccounter_NextAccountsPage_Call) RunAndReturn(run func(horizon.AccountsPage) (horizon.AccountsPage, error)) *MockAccounter_NextAccountsPage_Call
type MockLogger ¶
MockLogger is an autogenerated mock type for the Logger type
func NewMockLogger ¶
func NewMockLogger(t interface {
mock.TestingT
Cleanup(func())
}) *MockLogger
NewMockLogger creates a new instance of MockLogger. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockLogger) Debug ¶
func (_m *MockLogger) Debug(msg string, args ...interface{})
Debug provides a mock function with given fields: msg, args
func (*MockLogger) EXPECT ¶
func (_m *MockLogger) EXPECT() *MockLogger_Expecter
func (*MockLogger) Error ¶
func (_m *MockLogger) Error(msg string, args ...interface{})
Error provides a mock function with given fields: msg, args
func (*MockLogger) Info ¶
func (_m *MockLogger) Info(msg string, args ...interface{})
Info provides a mock function with given fields: msg, args
type MockLogger_Debug_Call ¶
MockLogger_Debug_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Debug'
func (*MockLogger_Debug_Call) Return ¶
func (_c *MockLogger_Debug_Call) Return() *MockLogger_Debug_Call
func (*MockLogger_Debug_Call) Run ¶
func (_c *MockLogger_Debug_Call) Run(run func(msg string, args ...interface{})) *MockLogger_Debug_Call
func (*MockLogger_Debug_Call) RunAndReturn ¶
func (_c *MockLogger_Debug_Call) RunAndReturn(run func(string, ...interface{})) *MockLogger_Debug_Call
type MockLogger_Error_Call ¶
MockLogger_Error_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Error'
func (*MockLogger_Error_Call) Return ¶
func (_c *MockLogger_Error_Call) Return() *MockLogger_Error_Call
func (*MockLogger_Error_Call) Run ¶
func (_c *MockLogger_Error_Call) Run(run func(msg string, args ...interface{})) *MockLogger_Error_Call
func (*MockLogger_Error_Call) RunAndReturn ¶
func (_c *MockLogger_Error_Call) RunAndReturn(run func(string, ...interface{})) *MockLogger_Error_Call
type MockLogger_Expecter ¶
type MockLogger_Expecter struct {
// contains filtered or unexported fields
}
func (*MockLogger_Expecter) Debug ¶
func (_e *MockLogger_Expecter) Debug(msg interface{}, args ...interface{}) *MockLogger_Debug_Call
Debug is a helper method to define mock.On call
- msg string
- args ...interface{}
func (*MockLogger_Expecter) Error ¶
func (_e *MockLogger_Expecter) Error(msg interface{}, args ...interface{}) *MockLogger_Error_Call
Error is a helper method to define mock.On call
- msg string
- args ...interface{}
func (*MockLogger_Expecter) Info ¶
func (_e *MockLogger_Expecter) Info(msg interface{}, args ...interface{}) *MockLogger_Info_Call
Info is a helper method to define mock.On call
- msg string
- args ...interface{}
type MockLogger_Info_Call ¶
MockLogger_Info_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Info'
func (*MockLogger_Info_Call) Return ¶
func (_c *MockLogger_Info_Call) Return() *MockLogger_Info_Call
func (*MockLogger_Info_Call) Run ¶
func (_c *MockLogger_Info_Call) Run(run func(msg string, args ...interface{})) *MockLogger_Info_Call
func (*MockLogger_Info_Call) RunAndReturn ¶
func (_c *MockLogger_Info_Call) RunAndReturn(run func(string, ...interface{})) *MockLogger_Info_Call
type MockMetricer ¶
MockMetricer is an autogenerated mock type for the Metricer type
func NewMockMetricer ¶
func NewMockMetricer(t interface {
mock.TestingT
Cleanup(func())
}) *MockMetricer
NewMockMetricer creates a new instance of MockMetricer. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockMetricer) EXPECT ¶
func (_m *MockMetricer) EXPECT() *MockMetricer_Expecter
func (*MockMetricer) MTLAPGaugeInc ¶
func (_m *MockMetricer) MTLAPGaugeInc(p MTLAPGaugeParams)
MTLAPGaugeInc provides a mock function with given fields: p
func (*MockMetricer) MTLAPGaugeReset ¶
func (_m *MockMetricer) MTLAPGaugeReset()
MTLAPGaugeReset provides a mock function with given fields:
type MockMetricer_Expecter ¶
type MockMetricer_Expecter struct {
// contains filtered or unexported fields
}
func (*MockMetricer_Expecter) MTLAPGaugeInc ¶
func (_e *MockMetricer_Expecter) MTLAPGaugeInc(p interface{}) *MockMetricer_MTLAPGaugeInc_Call
MTLAPGaugeInc is a helper method to define mock.On call
- p MTLAPGaugeParams
func (*MockMetricer_Expecter) MTLAPGaugeReset ¶
func (_e *MockMetricer_Expecter) MTLAPGaugeReset() *MockMetricer_MTLAPGaugeReset_Call
MTLAPGaugeReset is a helper method to define mock.On call
type MockMetricer_MTLAPGaugeInc_Call ¶
MockMetricer_MTLAPGaugeInc_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'MTLAPGaugeInc'
func (*MockMetricer_MTLAPGaugeInc_Call) Return ¶
func (_c *MockMetricer_MTLAPGaugeInc_Call) Return() *MockMetricer_MTLAPGaugeInc_Call
func (*MockMetricer_MTLAPGaugeInc_Call) Run ¶
func (_c *MockMetricer_MTLAPGaugeInc_Call) Run(run func(p MTLAPGaugeParams)) *MockMetricer_MTLAPGaugeInc_Call
func (*MockMetricer_MTLAPGaugeInc_Call) RunAndReturn ¶
func (_c *MockMetricer_MTLAPGaugeInc_Call) RunAndReturn(run func(MTLAPGaugeParams)) *MockMetricer_MTLAPGaugeInc_Call
type MockMetricer_MTLAPGaugeReset_Call ¶
MockMetricer_MTLAPGaugeReset_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'MTLAPGaugeReset'
func (*MockMetricer_MTLAPGaugeReset_Call) Return ¶
func (_c *MockMetricer_MTLAPGaugeReset_Call) Return() *MockMetricer_MTLAPGaugeReset_Call
func (*MockMetricer_MTLAPGaugeReset_Call) Run ¶
func (_c *MockMetricer_MTLAPGaugeReset_Call) Run(run func()) *MockMetricer_MTLAPGaugeReset_Call
func (*MockMetricer_MTLAPGaugeReset_Call) RunAndReturn ¶
func (_c *MockMetricer_MTLAPGaugeReset_Call) RunAndReturn(run func()) *MockMetricer_MTLAPGaugeReset_Call